#[non_exhaustive]pub enum ProfileLintCode {
DeadOverride,
SecurityRelaxation,
}Variants (Non-exhaustive)
This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.
DeadOverride
A layer sets a field to the value already in effect.
SecurityRelaxation
A layer dropped a security requirement a lower layer had enabled, but the result still satisfies the security floor.
Escalate to a hard error with
ProfileValidationOptions::forbid_security_relaxation.
Implementations